@@ -1,7 +1,7 @@
 package App::AcmeCpanlists;
 
-our $DATE = '2016-11-17'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-11-19'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,7 +11,7 @@ our %SPEC;
 
 $SPEC{':package'} = {
     v => 1.1,
-    summary => 'The Acme::CPANLists CLI (backend module)',
+    summary => 'The Acme::CPANLists CLI',
 };
 
 sub _complete_module {
@@ -558,7 +558,7 @@ sub list_entry_lists {
 }
 
 1;
-# ABSTRACT: The Acme::CPANLists CLI (backend module)
+# ABSTRACT: The Acme::CPANLists CLI
 
 __END__
 
@@ -568,11 +568,11 @@ __END__
 
 =head1 NAME
 
-App::AcmeCpanlists - The Acme::CPANLists CLI (backend module)
+App::AcmeCpanlists - The Acme::CPANLists CLI
 
 =head1 VERSION
 
-This document describes version 0.08 of App::AcmeCpanlists (from Perl distribution App-AcmeCpanlists), released on 2016-11-17.
+This document describes version 0.09 of App::AcmeCpanlists (from Perl distribution App-AcmeCpanlists), released on 2016-11-19.
 
 =head1 SYNOPSIS
 
